@@ -1,7 +1,7 @@
 """
 Common enums.
 """
-from algora.common.base import BaseEnum
+from algora.common.base_enum import BaseEnum
 
 
 class Order(BaseEnum):
